@@ -179,7 +179,7 @@ function(geneList, organism="hsapiens", idType="auto",verbose=TRUE){
        mart <- useMart("plants_mart",host="plants.ensembl.org")
        m <- try(mart <- useDataset(paste(organism,"_eg_gene",sep=""),mart),silent=TRUE)
    }else{
-       mart <- useMart("ENSEMBL_MART_ENSEMBL",host="www.ensembl.org")
+       mart <- useMart("ENSEMBL_MART_ENSEMBL",host="https://www.ensembl.org")
        m <- try(mart <- useDataset(paste(organism,"_gene_ensembl",sep=""),mart),silent=TRUE)
    }
    
@@ -415,7 +415,7 @@ function(inputNetwork, organism="hsapiens", idType="auto", edgeType="unweighted"
         if(file_ext(inputNetwork)!="net"){
             stop("The extension of the input file should be 'net'!\n")
         }else{
-            network <- read.graph(inputNetwork,format="ncol")
+            network <- read_graph_ncol(inputNetwork)
             if(edgeType=="weighted"){
                 if(is.null(E(network)$weight)){
                     stop("The input network does not contain edge weights. Please add the edge weights or change parameter 'edgeType' to 'unweigthed'!")
