@@ -1,7 +1,7 @@
 test_NetSAM <- function(){
-	data(inputNetwork)
+	inputNetworkDir <- system.file("extdata","exampleNetwork.net",package="NetSAM")
 	outputFileName <- paste(getwd(),"/NetSAM",sep="")
-	result <- NetSAM(inputNetwork, outputFileName)
+	result <- NetSAM(inputNetwork=inputNetworkDir, outputFileName=outputFileName)
 	checkTrue(!is.na(result[1]))
 	checkTrue(!is.na(result[2]))
 	checkTrue(!is.na(result[3]))
